[mlpack-svn] r13402 - mlpack/trunk/src/mlpack/tests

fastlab-svn at coffeetalk-1.cc.gatech.edu fastlab-svn at coffeetalk-1.cc.gatech.edu
Wed Aug 15 13:29:36 EDT 2012


Author: rcurtin
Date: 2012-08-15 13:29:36 -0400 (Wed, 15 Aug 2012)
New Revision: 13402

Modified:
   mlpack/trunk/src/mlpack/tests/tree_test.cpp
Log:
#240: Change expansion constant to base.


Modified: mlpack/trunk/src/mlpack/tests/tree_test.cpp
===================================================================
--- mlpack/trunk/src/mlpack/tests/tree_test.cpp	2012-08-15 17:29:25 UTC (rev 13401)
+++ mlpack/trunk/src/mlpack/tests/tree_test.cpp	2012-08-15 17:29:36 UTC (rev 13402)
@@ -1481,8 +1481,8 @@
   const size_t nodePoint = node.Point();
 
   // To ensure that this node satisfies the covering principle, we must ensure
-  // that the distance to each child is less than pow(expansionConstant, scale).
-  double maxDistance = pow(node.ExpansionConstant(), node.Scale());
+  // that the distance to each child is less than pow(base, scale).
+  double maxDistance = pow(node.Base(), node.Scale());
   for (size_t i = 0; i < node.NumChildren(); ++i)
   {
     const size_t childPoint = node.Child(i).Point();
@@ -1530,7 +1530,7 @@
 
   // Make sure the distance is at least the following value (in accordance with
   // the separation principle of cover trees).
-  double minDistance = pow(constantNode.ExpansionConstant(),
+  double minDistance = pow(constantNode.Base(),
       constantNode.Scale());
 
   double distance = MetricType::Evaluate(dataset.col(constantPoint),




More information about the mlpack-svn mailing list